@@ -47,6 +47,7 @@
 #define PARAM_CPUWEIGHT		14
 #define PARAM_CPULIMIT		15
 #define PARAM_CPUUNITS		16
+#define PARAM_VCPUS		17
 
 #define PARAM_IP_ADD		18
 #define PARAM_IP_DEL		19
@@ -113,6 +114,8 @@
 #define PARAM_RESET_UB		340
 #define PARAM_VETH_ADD		341
 #define PARAM_VETH_DEL		342
+#define PARAM_VEID		343
+#define PARAM_NAME		344
 
 #define PARAM_LINE		"e:p:f:t:i:l:k:a:b:n:x:h"
 #endif
