@@ -69,7 +69,7 @@ void usage()
 "vzctl set veid [--save] [--setmode restart|ignore]\n"
 "   [--ipadd <addr>] [--ipdel <addr>|all] [--hostname <name>]\n"
 "   [--nameserver <addr>] [--searchdomain <name>] [--onboot yes|no]\n"
-"   [--userpasswd <user>:<passwd>] [--cpuunits <N>] [--cpulimit <N>]\n"
+"   [--userpasswd <user>:<passwd>] [--cpuunits <N>] [--cpulimit <N>] [--cpus <N>]\n"
 "   [--diskspace <soft>[:<hard>]] [--diskinodes <soft>[:<hard>]]\n"
 "   [--quotatime <N>] [--quotaugidlimit <N>]\n"
 "   [--noatime yes|no] [--capability <name>:on|off ...]\n"
@@ -210,9 +210,12 @@ int main(int argc, char *argv[], char *envp[])
 		goto error;
 	}
 	if (parse_int(argv[2], &veid)) {
-		fprintf(stderr, "Bad VPS id %s\n", argv[2]);
-		ret = VZ_INVALID_PARAMETER_VALUE;
-		goto error;
+		veid = get_veid_by_name(argv[2]);
+		if (veid < 0) {
+			fprintf(stderr, "Bad VPS id %s\n", argv[2]);
+			ret = VZ_INVALID_PARAMETER_VALUE;
+			goto error;
+		}
 	}
 	argc -= 2; argv += 2;
 	/* Read global config file */
